pub enum Error {
InvalidIdentifier {
attempted: String,
reason: &'static str,
},
EmptyRegexPattern,
InvalidRegexFlag {
flag: char,
},
UnbalancedTemplate {
quasis: usize,
expressions: usize,
},
}Expand description
All errors that arise when constructing AST nodes from raw input.
Variants
InvalidIdentifier
An identifier was empty or contained an illegal character.
Fields
EmptyRegexPattern
A regex literal pattern was empty.
InvalidRegexFlag
A regex literal carried a flag character not recognised by ECMA-262.
UnbalancedTemplate
A template literal had a different number of quasis than expressions
allow (must satisfy quasis.len() == expressions.len() + 1).